@@ -16,6 +16,7 @@
 #' @param label.x text in x
 #' @param label.y text in y
 #' @param labelsize Label size
+#' @param legendsize Title legend size
 #' @param axissize Axis size
 #' @param add.streets.x Adds streets by separating treatments in row or column. The user must supply a numeric vector grouping the rows or columns that must be together. See the example.
 #' @param add.streets.y Adds streets by separating treatments in row or column. The user must supply a numeric vector grouping the rows or columns that must be together. See the example.
@@ -102,6 +103,7 @@ sketch=function(trat,
                 label.x="",
                 label.y="",
                 axissize=12,
+                legendsize=12,
                 labelsize=4,
                 export.csv=FALSE,
                 comment.caption=NULL){
@@ -346,10 +348,10 @@ sketch=function(trat,
   if(pos=="line"){graph=ggplot(data,aes(x=x,y=y))+
     geom_tile(aes(fill=separate),color="black")+
     labs(x=label.x,y=label.y,fill="Treatments")+
-    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
+    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))}
   if(pos=="column"){graph=ggplot(data,aes(y=x,x=y,fill=separate))+
     geom_tile(color="black")+labs(x=label.x,y=label.y,fill="Treatments")+
-    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
+    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))}
 
   if(is.na(add.streets.x[1])==FALSE | is.na(add.streets.y[1])==FALSE){
     if(pos=="line"){
@@ -357,7 +359,7 @@ sketch=function(trat,
       graph=ggplot(data,aes(x=x,y=y,fill=separate))+
         geom_tile(color="black")+
         labs(x=label.x,y=label.y,fill="Treatments")+
-        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
+        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))
 
       if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
         ruas1=rep(add.streets.x,(length(data$x)/length(add.streets.x)))
@@ -382,7 +384,7 @@ sketch=function(trat,
       graph=ggplot(data,aes(y=x,x=y,fill=separate))+
         geom_tile(color="black")+
         labs(x=label.x,y=label.y,fill="Treatments")+
-        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
+        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))
 
       if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
         ruas1=rep(add.streets.x,e=(length(data$x)/length(add.streets.x)))
@@ -436,7 +438,7 @@ sketch=function(trat,
       graph=ggplot(data,aes(x=x,y=block,fill=separate))+
         geom_tile(color="black")+
         labs(x=label.x,y="Block",fill="Treatments")+
-        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
+        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))
 
       if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
         ruas1=rep(add.streets.x,(length(data$x)/length(add.streets.x)))
@@ -462,7 +464,7 @@ sketch=function(trat,
       graph=ggplot(data,aes(y=x,x=block,fill=separate))+
         geom_tile(color="black")+
         labs(x="Block",y=label.y,fill="Treatments")+
-        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
+        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))
 
       if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
         ruas1=rep(add.streets.x,e=(length(data$x)/length(add.streets.x)))
@@ -504,7 +506,7 @@ sketch=function(trat,
 
   graph=ggplot(data,aes(x=row,y=col,fill=separate))+
     geom_tile(color="black")+labs(x="Row",y="Column",fill="Treatments")+
-    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
+    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))
 
   if(is.na(add.streets.x[1])==FALSE | is.na(add.streets.y[1])==FALSE){
     data$row=factor(data$row,levels = rev(unique(data$row)))
@@ -556,17 +558,17 @@ sketch=function(trat,
 
   if(pos=="column"){graph=ggplot(data,aes(x=y,y=x,fill=separate))+
     geom_tile(color="black")+labs(x=label.x,y=label.y,fill="Treatments")+
-    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
+    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))}
   if(pos=="line"){graph=ggplot(data,aes(x=x,y=y,fill=separate))+
     geom_tile(color="black")+labs(x=label.x,y=label.y,fill="Treatments")+
-    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
+    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))}
 
   if(is.na(add.streets.x[1])==FALSE | is.na(add.streets.y[1])==FALSE){
     if(pos=="line"){
       data$y=factor(data$y,levels = rev(unique(data$y)))
       graph=ggplot(data,aes(x=x,y=y,fill=separate))+
         geom_tile(color="black")+labs(x=label.x,y=label.y,fill="Treatments")+
-        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
+        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))
 
       if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
         ruas1=rep(add.streets.x,(length(data$x)/length(add.streets.x)))
@@ -592,7 +594,7 @@ sketch=function(trat,
       graph=ggplot(data,aes(y=x,x=y,fill=separate))+
         geom_tile(color="black")+
         labs(x=label.x,y=label.y,fill="Treatments")+
-        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
+        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))
 
       if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
         ruas1=rep(add.streets.x,e=(length(data$x)/length(add.streets.x)))
@@ -638,16 +640,16 @@ sketch=function(trat,
 
   if(pos=="column"){graph=ggplot(data,aes(y=x,x=block,fill=separate))+
     geom_tile(color="black")+labs(x="Block",y=label.y,fill="Treatments")+
-    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
+    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))}
   if(pos=="line"){graph=ggplot(data,aes(y=block,x=x,fill=separate))+
     geom_tile(color="black")+labs(x=label.x,y="Block",fill="Treatments")+
-    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
+    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))}
   if(is.na(add.streets.x[1])==FALSE | is.na(add.streets.y[1])==FALSE){
     if(pos=="line"){
       data$y=factor(data$block,levels = rev(unique(data$block)))
       graph=ggplot(data,aes(x=x,y=y,fill=separate))+
         geom_tile(color="black")+labs(x=label.x,y="Block",fill="Treatments")+
-        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
+        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))
 
       if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
         ruas1=rep(add.streets.x,(length(data$x)/length(add.streets.x)))
@@ -673,7 +675,7 @@ sketch=function(trat,
       graph=ggplot(data,aes(y=x,x=y,fill=separate))+
         geom_tile(color="black")+
         labs(x="Block",y=label.y,fill="Treatments")+
-        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
+        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))
 
       if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
         ruas1=rep(add.streets.x,e=(length(data$x)/length(add.streets.x)))
@@ -760,7 +762,7 @@ sketch=function(trat,
         ylab("")+xlab("")+
         geom_text(aes(label=paste(t1,t2)))+
         theme_classic()+theme(axis.line = element_blank(),
-                              axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),
+                              axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize),
                               strip.text = element_text(size=12))}
     requireNamespace("cowplot")
     graph=do.call("plot_grid", c(graphs, ncol=length(levels(book$block))))
@@ -789,17 +791,17 @@ sketch=function(trat,
 
   if(pos=="column"){graph=ggplot(data,aes(x=y,y=x,fill=separate))+
     geom_tile(color="black")+labs(x=label.x,y=label.y,fill="Treatments")+
-    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
+    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))}
   if(pos=="line"){graph=ggplot(data,aes(x=x,y=y,fill=separate))+
     geom_tile(color="black")+labs(x=label.x,y=label.y,fill="Treatments")+
-    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
+    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))}
 
   if(is.na(add.streets.x[1])==FALSE | is.na(add.streets.y[1])==FALSE){
     if(pos=="line"){
       data$y=factor(data$y,levels = rev(unique(data$y)))
       graph=ggplot(data,aes(x=x,y=y,fill=separate))+
         geom_tile(color="black")+labs(x=label.x,y=label.y,fill="Treatments")+
-        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
+        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))
 
       if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
         ruas1=rep(add.streets.x,(length(data$x)/length(add.streets.x)))
@@ -825,7 +827,7 @@ sketch=function(trat,
       graph=ggplot(data,aes(y=x,x=y,fill=separate))+
         geom_tile(color="black")+
         labs(x=label.x,y=label.y,fill="Treatments")+
-        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
+        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))
 
       if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
         ruas1=rep(add.streets.x,e=(length(data$x)/length(add.streets.x)))
@@ -878,17 +880,17 @@ sketch=function(trat,
 
     if(pos=="column"){graph=ggplot(data,aes(y=x,x=block,fill=separate))+
       geom_tile(color="black")+labs(x="Block",y=label.y,fill="Treatments")+
-      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
+      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))}
     if(pos=="line"){graph=ggplot(data,aes(y=block,x=x,fill=separate))+
       geom_tile(color="black")+labs(x=label.x,y="Block",fill="Treatments")+
-      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
+      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))}
 
     if(is.na(add.streets.x[1])==FALSE | is.na(add.streets.y[1])==FALSE){
       if(pos=="line"){
         data$y=factor(data$block,levels = rev(unique(data$block)))
         graph=ggplot(data,aes(x=x,y=y,fill=separate))+
           geom_tile(color="black")+labs(x=label.x,y="Block",fill="Treatments")+
-          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
+          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))
 
         if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
           ruas1=rep(add.streets.x,(length(data$x)/length(add.streets.x)))
@@ -914,7 +916,7 @@ sketch=function(trat,
         graph=ggplot(data,aes(y=x,x=y,fill=separate))+
           geom_tile(color="black")+
           labs(x="Block",y=label.y,fill="Treatments")+
-          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
+          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))
 
         if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
           ruas1=rep(add.streets.x,e=(length(data$x)/length(add.streets.x)))
@@ -967,16 +969,16 @@ sketch=function(trat,
 
     if(pos=="line"){graph=ggplot(data,aes(x=y,y=x,fill=separate))+
       geom_tile(color="black")+labs(x=label.x,y=label.y,fill="Treatments")+
-      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
+      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))}
     if(pos=="column"){graph=ggplot(data,aes(x=x,y=y,fill=separate))+
       geom_tile(color="black")+labs(x=label.x,y=label.y,fill="Treatments")+
-      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
+      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))}
     if(is.na(add.streets.x[1])==FALSE | is.na(add.streets.y[1])==FALSE){
       if(pos=="line"){
         data$y=factor(data$y,levels = rev(unique(data$y)))
         graph=ggplot(data,aes(x=x,y=y,fill=separate))+
           geom_tile(color="black")+labs(x=label.x,y=label.y,fill="Treatments")+
-          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
+          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))
 
         if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
           ruas1=rep(add.streets.x,(length(data$x)/length(add.streets.x)))
@@ -1002,7 +1004,7 @@ sketch=function(trat,
         graph=ggplot(data,aes(y=x,x=y,fill=separate))+
           geom_tile(color="black")+
           labs(x=label.x,y=label.y,fill="Treatments")+
-          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
+          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))
 
         if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
           ruas1=rep(add.streets.x,e=(length(data$x)/length(add.streets.x)))
@@ -1058,17 +1060,17 @@ sketch=function(trat,
 
     if(pos=="line"){graph=ggplot(data,aes(x=y,y=x,fill=separate))+
       geom_tile(color="black")+labs(x="block",y=label.y,fill="Treatments")+
-      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
+      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))}
     if(pos=="column"){graph=ggplot(data,aes(x=x,y=y,fill=separate))+
       geom_tile(color="black")+labs(x=label.x,y="block",fill="Treatments")+
-      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
+      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))}
 
     if(is.na(add.streets.x[1])==FALSE | is.na(add.streets.y[1])==FALSE){
       if(pos=="line"){
         data$y=factor(data$y,levels = rev(unique(data$y)))
         graph=ggplot(data,aes(x=x,y=y,fill=separate))+
           geom_tile(color="black")+labs(x=label.x,y="Block",fill="Treatments")+
-          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
+          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))
 
         if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
           ruas1=rep(add.streets.x,e=(length(data$x)/length(add.streets.x)))
@@ -1094,7 +1096,7 @@ sketch=function(trat,
         graph=ggplot(data,aes(y=x,x=y,fill=separate))+
           geom_tile(color="black")+
           labs(x="Block",y=label.y,fill="Treatments")+
-          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
+          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))
 
         if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
           ruas1=rep(add.streets.x,(length(data$x)/length(add.streets.x)))
@@ -1157,17 +1159,17 @@ sketch=function(trat,
 
     if(pos=="line"){graph=ggplot(data,aes(x=y,y=x,fill=separate))+
       geom_tile(color="black")+labs(x="block",y=label.y,fill="Treatments")+
-      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
+      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))}
     if(pos=="column"){graph=ggplot(data,aes(x=x,y=y,fill=separate))+
       geom_tile(color="black")+labs(x=label.x,y="block",fill="Treatments")+
-      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
+      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))}
 
     if(is.na(add.streets.x[1])==FALSE | is.na(add.streets.y[1])==FALSE){
       if(pos=="line"){
         data$y=factor(data$y,levels = rev(unique(data$y)))
         graph=ggplot(data,aes(x=x,y=y,fill=separate))+
           geom_tile(color="black")+labs(x=label.x,y="Block",fill="Treatments")+
-          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
+          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))
 
         if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
           ruas1=rep(add.streets.x,(length(data$x)/length(add.streets.x)))
@@ -1193,7 +1195,7 @@ sketch=function(trat,
         graph=ggplot(data,aes(y=x,x=y,fill=separate))+
           geom_tile(color="black")+
           labs(x="Block",y=label.y,fill="Treatments")+
-          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
+          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),legend.title=element_text(size=legendsize))
 
         if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
           ruas1=rep(add.streets.x,e=(length(data$x)/length(add.streets.x)))
