@@ -20,6 +20,7 @@
 #' @param addmean Plot the average value on the graph (\emph{default} is TRUE)
 #' @param textsize Font size of the texts and titles of the axes
 #' @param labelsize Font size of the labels
+#' @param pointsize Point size
 #' @param family Font family
 #' @param dec Number of cells
 #' @param geom Graph type (columns - "bar" or segments "point")
@@ -78,6 +79,7 @@ DBCT=function(trat,
               xlab="Independent",
               textsize=12,
               labelsize=5,
+              pointsize=4.5,
               error=TRUE,
               family="sans",
               sup=0,
@@ -418,7 +420,7 @@ DBCT=function(trat,
     grafico=ggplot(dadosm,aes(y=media,
                               x=time))+
       geom_point(aes(shape=factor(trat, levels=unique(as.character(trat))),
-                     group=factor(trat, levels=unique(as.character(trat)))),size=3)+
+                     group=factor(trat, levels=unique(as.character(trat)))),size=pointsize)+
       geom_line(aes(lty=factor(trat, levels=unique(as.character(trat))),
                     group=factor(trat, levels=unique(as.character(trat)))),size=0.8)+
       ylab(ylab)+
