@@ -19,6 +19,7 @@
 #' @param addmean Plot the average value on the graph (\emph{default} is TRUE)
 #' @param textsize Font size of the texts and titles of the axes
 #' @param labelsize Font size of the labels
+#' @param pointsize Point size
 #' @param family Font family
 #' @param dec Number of cells
 #' @param geom Graph type (columns - "bar" or segments "point")
@@ -54,6 +55,7 @@
 #' attach(simulate1)
 #' with(simulate1, DICT(trat, tempo, resp))
 #' with(simulate1, DICT(trat, tempo, resp,geom="bar",sup=40))
+#' with(simulate1, DICT(trat, tempo, resp,geom="point",sup=40,))
 
 DICT=function(trat,
               time,
@@ -71,6 +73,7 @@ DICT=function(trat,
               error=TRUE,
               textsize=12,
               labelsize=5,
+              pointsize=4.5,
               family="sans",
               sup=0,
               addmean=FALSE,
@@ -444,7 +447,7 @@ grafico=ggplot(dadosm,aes(y=media,
                           x=time))+
   geom_point(aes(shape=factor(trat,
                               levels=unique(as.character(trat))),
-                 group=factor(trat,levels=unique(as.character(trat)))),size=3)+
+                 group=factor(trat,levels=unique(as.character(trat)))),size=pointsize)+
   geom_line(aes(lty=factor(trat,levels=unique(as.character(trat))),
                 group=factor(trat,levels=unique(as.character(trat)))),size=0.8)+
   ylab(ylab)+
